A lookup table that maps each supported distribution family to the field name used to link observed data, the random-value generator, and the remaining parameter names for that family.
A lookup table that maps each supported distribution family to the field name used to link observed data, the random-value generator, and the remaining parameter names for that family.