A vector of strings that define which input types are allowed in the column
labeled type in the data slot of a FIMSFrame object. Strings are composed
of words separated by underscores, e.g., "weight_at_age".
A vector of strings that define which input types are allowed in the column
labeled type in the data slot of a FIMSFrame object. Strings are composed
of words separated by underscores, e.g., "weight_at_age".