Get a vector of data to be passed to a FIMS module from a FIMSFrame object
Source:R/fimsframe.R
model_.RdThere is an accessor function for each data type needed to run a FIMS model.
A FIMS model accepts vectors of data and thus each of the model_*()
functions, where the star can be replaced with the data type separated by
underscores, e.g., weight_at_age. These accessor functions are the preferred
way to pass data to a FIMS module because the data will have the appropriate
indexing.
Usage
model_landings(x, fleet_name)
# S4 method for class 'FIMSFrame'
model_landings(x, fleet_name)
# S4 method for class 'data.frame'
model_landings(x, fleet_name)
model_index(x, fleet_name)
# S4 method for class 'FIMSFrame'
model_index(x, fleet_name)
# S4 method for class 'data.frame'
model_index(x, fleet_name)
model_age_comp(x, fleet_name)
# S4 method for class 'FIMSFrame'
model_age_comp(x, fleet_name)
# S4 method for class 'data.frame'
model_age_comp(x, fleet_name)
model_length_comp(x, fleet_name)
# S4 method for class 'FIMSFrame'
model_length_comp(x, fleet_name)
# S4 method for class 'data.frame'
model_length_comp(x, fleet_name)
model_weight_at_age(x)
# S4 method for class 'FIMSFrame'
model_weight_at_age(x)
# S4 method for class 'data.frame'
model_weight_at_age(x)
model_age_to_length_conversion(x, fleet_name)
# S4 method for class 'FIMSFrame'
model_age_to_length_conversion(x, fleet_name)
# S4 method for class 'data.frame'
model_age_to_length_conversion(x, fleet_name)Arguments
- x
An object returned from
FIMSFrame().- fleet_name
A string, or vector of strings, specifying the name of the fleet(s) of interest that you want landings data for. The strings must exactly match strings in the column
"name"ofget_data(x).
Value
All of the model_*() functions return vectors of data. Currently, the
order of the data is the same order as the data frame because no arranging
is done in FIMSFrame() and the function just extracts the appropriate
column.