Use ggplot2::geom_point() to plot the information stored in the data slot
of the FIMSFrame class.
Value
A ggplot2 object is returned that uses stockplotr::theme_noaa().
There will be one panel per input type with fleet-specific information
denoted using colors.